@@ -2,20 +2,21 @@
     ulmo
     ~~~~
 
-    an open source library for clean, simple and fast access to public hydrology and climatology data
+    An open source library for clean, simple and fast access to public hydrology and climatology data
 """
 from __future__ import (absolute_import, division, print_function)
 
 # ulmo version PEP-0440
-__version__ = '0.8.5'
+__version__ = '0.8.8'
 
 from . import cdec
 from . import cpc
 from . import cuahsi
-from . import twc
+from . import lcra
+from . import nasa
 from . import ncdc
+from . import noaa
+from . import twc
 from . import usace
 from . import usgs
 from . import util
-from . import lcra
-from . import nasa
\ No newline at end of file
